@@ -95,8 +95,6 @@ class LightwoodBackend():
             data_subtype = col_stats['typing']['data_subtype']
             data_type = col_stats['typing']['data_type']
 
-            lightwood_data_type = None
-
             other_keys = {'encoder_attrs': {}}
             if data_type == DATA_TYPES.NUMERIC:
                 lightwood_data_type = 'numeric'
@@ -132,6 +130,9 @@ class LightwoodBackend():
                 'type': lightwood_data_type
             }
 
+            if data_subtype == DATA_SUBTYPES.SHORT:
+                col_config['encoder_class'] = lightwood.encoders.text.short.ShortTextEncoder
+
             if col_name in self.transaction.lmd['weight_map']:
                 col_config['weights'] = self.transaction.lmd['weight_map'][col_name]
 
