@@ -46,15 +46,14 @@ class DATA_TYPES:
     TEXT = 'Text'
 
 
-class DATA_TYPES_SUBTYPES:
-    subtypes = {
-        DATA_TYPES.NUMERIC: [DATA_SUBTYPES.INT, DATA_SUBTYPES.FLOAT, DATA_SUBTYPES.BINARY],
-        DATA_TYPES.DATE: [DATA_SUBTYPES.DATE, DATA_SUBTYPES.TIMESTAMP],
-        DATA_TYPES.CATEGORICAL: [DATA_SUBTYPES.SINGLE, DATA_SUBTYPES.MULTIPLE],
-        DATA_TYPES.FILE_PATH: [DATA_SUBTYPES.IMAGE, DATA_SUBTYPES.VIDEO, DATA_SUBTYPES.AUDIO],
-        DATA_TYPES.SEQUENTIAL: [DATA_SUBTYPES.ARRAY],
-        DATA_TYPES.TEXT: [DATA_SUBTYPES.SHORT, DATA_SUBTYPES.RICH],
-    }
+DATA_TYPES_SUBTYPES = {
+    DATA_TYPES.NUMERIC: [DATA_SUBTYPES.INT, DATA_SUBTYPES.FLOAT, DATA_SUBTYPES.BINARY],
+    DATA_TYPES.DATE: [DATA_SUBTYPES.DATE, DATA_SUBTYPES.TIMESTAMP],
+    DATA_TYPES.CATEGORICAL: [DATA_SUBTYPES.SINGLE, DATA_SUBTYPES.MULTIPLE],
+    DATA_TYPES.FILE_PATH: [DATA_SUBTYPES.IMAGE, DATA_SUBTYPES.VIDEO, DATA_SUBTYPES.AUDIO],
+    DATA_TYPES.SEQUENTIAL: [DATA_SUBTYPES.ARRAY],
+    DATA_TYPES.TEXT: [DATA_SUBTYPES.SHORT, DATA_SUBTYPES.RICH],
+}
 
 
 class ORDER_BY_KEYS:
