@@ -23,9 +23,9 @@ def _get_memory_optimizations(df):
 
     mem_usage_ratio = df_memory/total_memory
 
-    sample_for_analysis = True if mem_usage_ratio >= 0.05 else False
-    sample_for_training = True if mem_usage_ratio >= 0.15 else False
-    disable_lightwood_transform_cache = True if mem_usage_ratio >= 0.15 else False
+    sample_for_analysis = True if mem_usage_ratio >= 0.1 or len(df) > pow(10,4) else False
+    sample_for_training = True if mem_usage_ratio >= 0.5 else False
+    disable_lightwood_transform_cache = True if mem_usage_ratio >= 0.2 else False
 
     return sample_for_analysis, sample_for_training, disable_lightwood_transform_cache
 
@@ -50,6 +50,7 @@ def _prepare_sample_settings(user_provided_settings,
 
     # We need the settings to be JSON serializable, so the actual function will be stored in heavy metadata
     sample_settings['sample_function'] = sample_settings['sample_function'].__name__
+
     return sample_settings, sample_function
 
 
@@ -66,6 +67,7 @@ class Predictor:
         self.uuid = str(uuid.uuid1())
         self.log = MindsdbLogger(log_level=log_level, uuid=self.uuid)
         self.breakpoint = None
+        self.transaction = None
 
         if CONFIG.CHECK_FOR_UPDATES:
             check_for_updates()
@@ -160,6 +162,9 @@ class Predictor:
                                                         sample_for_analysis,
                                                         sample_for_training)
 
+            self.log.warning(f'Sample for analysis: {sample_for_analysis}')
+            self.log.warning(f'Sample for training: {sample_for_training}')
+
             if len(predict_columns) == 0:
                 error = 'You need to specify a column to predict'
                 self.log.error(error)
@@ -172,7 +177,7 @@ class Predictor:
             the server doesn't handle non-file data sources at the moment, so this shouldn't prove an issue,
             once we want to support datasources such as s3 and databases for the server we need to add name as a concept (or, preferably, before that)
             """
-            data_source_name = from_data if isinstance(from_data, str) else 'Unkown'
+            data_source_name = from_ds.name()
 
             heavy_transaction_metadata = dict(
                 name=self.name,
@@ -242,11 +247,12 @@ class Predictor:
                 if old_hmd['from_data'] is not None:
                     heavy_transaction_metadata['from_data'] = old_hmd['from_data']
 
-            LearnTransaction(session=self,
+            self.transaction = LearnTransaction(session=self,
                         light_transaction_metadata=light_transaction_metadata,
                         heavy_transaction_metadata=heavy_transaction_metadata,
                         logger=self.log)
 
+
     def test(self, when_data, accuracy_score_functions, score_using='predicted_value', predict_args=None):
         """
         :param when_data: use this when you have data in either a file, a pandas data frame, or url to a file that you want to predict from
@@ -272,7 +278,13 @@ class Predictor:
                 else:
                     acc_f = accuracy_score_functions
 
-                accuracy_dict[f'{col}_accuracy'] = acc_f([x[f'__observed_{col}'] for x in predictions], [x.explanation[col][score_using] for x in predictions])
+                if score_using is None:
+                    predicted = [x.explanation[col] for x in predictions]
+                else:
+                    predicted = [x.explanation[col][score_using] for x in predictions]
+
+                real = [x[f'__observed_{col}'] for x in predictions]
+                accuracy_dict[f'{col}_accuracy'] = acc_f(real, predicted)
 
             return accuracy_dict
 
@@ -332,7 +344,7 @@ class Predictor:
                 breakpoint=self.breakpoint
             )
 
-            transaction = PredictTransaction(session=self,
+            self.transaction = PredictTransaction(session=self,
                                     light_transaction_metadata=light_transaction_metadata,
                                     heavy_transaction_metadata=heavy_transaction_metadata)
-            return transaction.output_data
+            return self.transaction.output_data
