@@ -4,7 +4,6 @@ import boto3
 from botocore import UNSIGNED
 from botocore.client import Config
 
-
 from mindsdb_native.libs.data_types.data_source import DataSource
 from mindsdb_native.libs.data_sources.file_ds import FileDS
 from mindsdb_native import F
@@ -12,7 +11,12 @@ from mindsdb_native import F
 
 class S3DS(DataSource):
 
-    def _setup(self, bucket_name, file_path, access_key=None, secret_key=None, use_default_credentails=False):
+    def _setup(self, bucket_name, file_path, access_key=None,
+               secret_key=None,use_default_credentails=False):
+
+        self._bucket_name = bucket_name
+        self._file_name = os.path.basename(file_path)
+
         if access_key is not None and secret_key is not None:
             s3 = boto3.client('s3', aws_access_key_id=access_key, aws_secret_access_key=secret_key)
         elif use_default_credentails:
@@ -31,8 +35,10 @@ class S3DS(DataSource):
     def _cleanup(self):
         os.remove(self.tmp_file_name)
 
-if __name__ == "__main__":
-    from mindsdb_native import Predictor
-    mdb = Predictor(name='analyse_dataset_test_predictor')
-    s3_ds = S3DS(bucket_name='mindsdb-example-data',file_path='home_rentals.csv', access_key=None, secret_key=None)
-    F.analyse_dataset(from_data=s3_ds)
+
+    def name(self):
+        return '{}: {}/{}'.format(
+            self.__class__.__name__,
+            self._bucket_name,
+            self._file_name
+        )
\ No newline at end of file
